"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var Encoder_1 = __importDefault(require("../Encoder"));
var testAccountKeyJson = require('../../.keys/shirahama-test-d6301-b798cfcf7b07.json');
describe('Encoder', function () {
    test('typecheck', function () {
        expect(Encoder_1.default.encode).toBeInstanceOf(Function);
        expect(Encoder_1.default.decode).toBeInstanceOf(Function);
    });
    test('encode', function () {
        var encodedData = Encoder_1.default.encode(testAccountKeyJson);
        expect(encodedData).toEqual(expect.any(String));
    });
    test('encode => decode', function () {
        var encodedData = Encoder_1.default.encode(testAccountKeyJson);
        var decodedData = Encoder_1.default.decode(encodedData);
        expect(decodedData).toBeInstanceOf(Object);
        expect(decodedData).toEqual(testAccountKeyJson);
    });
    test('toAccountKeyFromBase64', function () {
        var encodedData = Encoder_1.default.encode(testAccountKeyJson);
        var accountKey = Encoder_1.default.toAccountKeyFromBase64(encodedData);
        expect(accountKey.project_id).toEqual(expect.any(String));
        expect(accountKey.type).toEqual(expect.any(String));
        expect(accountKey.client_id).not.toEqual('error or empty');
        expect(accountKey.type).not.toEqual('error or empty');
    });
    test('failed: decode', function () {
        console.error = jest.fn();
        var decodedData = Encoder_1.default.decode('FAILED_TEXT');
        // @ts-ignore
        expect(decodedData.success).toEqual(false);
        expect(console.error).toHaveBeenCalled();
    });
    test('failed: toWebAppsApiKeyFromBase64', function () {
        console.error = jest.fn();
        console.warn = jest.fn();
        var apiKey = Encoder_1.default.toWebAppsApiKeyFromBase64('FAILED_TEXT');
        expect(apiKey.apiKey).toEqual('error or empty');
    });
});
