import { Base64 } from 'js-base64'

export interface ServiceAccountKey {
  type: string
  project_id: string
  client_id: string
}

export interface WebAppsApiKey {
  apiKey: string
  projectId: string
  authDomain: string
}

export default class Encoder {
  public static encode(json: Object | JSON): string {
    return Base64.encode(JSON.stringify(json))
  }

  public static decode(
    str: string,
  ): { success: boolean; error: string | null } | WebAppsApiKey {
    try {
      const decodingData = Base64.decode(str)
      const json = JSON.parse(decodingData)
      return json
    } catch (e) {
      console.error('Decoding error', e)
      return { success: false, error: e.code }
    }
  }

  public static toWebAppsApiKeyFromBase64(str: string): WebAppsApiKey {
    const encodedData = this.decode(str)
    if (
      'apiKey' in encodedData &&
      'projectId' in encodedData &&
      'authDomain' in encodedData
    ) {
      return encodedData
    }
    console.warn('Failed decoding Web apps api key')
    return {
      apiKey: 'error or empty',
      projectId: 'error or empty',
      authDomain: 'error or empty',
      ...encodedData,
    }
  }

  public static toAccountKeyFromBase64(str: string): ServiceAccountKey {
    const encodedData = this.decode(str)
    if (
      'project_id' in encodedData &&
      'type' in encodedData &&
      'client_id' in encodedData
    ) {
      return encodedData
    }
    console.warn('Failed decoding service account key')
    console.info('encodedData', encodedData)
    return {
      project_id: 'error or empty',
      client_id: 'error or empty',
      type: 'error or empty',
      ...encodedData,
    }
  }
}
